pub fn validate_context(history: &[Message]) -> Result<(), StateError>Expand description
Every tool call has exactly one result in the immediately following batch.
pub fn validate_context(history: &[Message]) -> Result<(), StateError>Every tool call has exactly one result in the immediately following batch.